<?php

namespace App\Http\Controllers;

use App\CarTypes;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;

class CarTypesController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $Select_db = DB::table('lkp_cartypes')
            ->select('lkp_cartypes.id as id', 'carName', 'arabicName', 'carImage', 'Counterprice', 'priceByDistence',
                'priceByTime', 'rushHoursPBD', 'rushHoursPBT', 'NumberOfSeat', 'status_id', 'active', 'created_at', 'updated_at')
            ->leftJoin('lkp_active', 'lkp_cartypes.status_id', '=', 'lkp_active.id')
            ->where('lkp_cartypes.companyId', Auth::user()->companyId);
        if (request()->ajax()) {
            $data = $Select_db->get();
            return datatables()->of($data)->make(true);
        }
        $data = $Select_db->get();
        //$CarTypes = CarTypes::orderBy('created_at', 'desc')->paginate(10);
        return view('CarTypes.index');
        //return view('custom_search', compact('country_name'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $lkp_active = DB::select('SELECT id,active from lkp_active order by id');
        return view('CarTypes.create')->with(compact('lkp_active'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        /* $this->validate($request, [
             'name' => ['required', 'string', 'max:255'],
             'email' => ['required', 'string', 'email', 'max:255', 'unique:CarTypes'],
             'password' => ['required', 'string', 'min:8', 'confirmed'],
         ]);
         */
        $CarTypes = new CarTypes;
        $CarTypes->arabicName = $request->input('arabicName');
        $CarTypes->Counterprice = $request->input('Counterprice');
        $CarTypes->priceByDistence = $request->input('priceByDistence');
        $CarTypes->priceByTime = $request->input('priceByTime');
        $CarTypes->rushHoursPBD = $request->input('rushHoursPBD');
        $CarTypes->rushHoursPBT = $request->input('rushHoursPBT');
        $CarTypes->NumberOfSeat = $request->input('NumberOfSeat');
        $CarTypes->status_id = $request->input('status_id');
        $CarTypes->companyId = Auth::user()->companyId;
        $CarTypes->save();
        return redirect('/CarTypes')->with('success', 'Done successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $Select_db = DB::table('lkp_cartypes')
            ->select('lkp_cartypes.id as id', 'carName', 'arabicName', 'carImage', 'Counterprice', 'priceByDistence',
                'priceByTime', 'rushHoursPBD', 'rushHoursPBT', 'NumberOfSeat', 'status_id', 'active', 'created_at', 'updated_at')
            ->leftJoin('lkp_active', 'lkp_cartypes.status_id', '=', 'lkp_active.id')
            ->where('lkp_cartypes.companyId', Auth::user()->companyId)
            ->where('lkp_cartypes.id', $id);
        $CarTypes = $Select_db->first();
        //$CarTypes = CarTypes::find($id);
        return view('CarTypes.show')->with('CarTypes', $CarTypes);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $lkp_active = DB::select('SELECT id,active from lkp_active order by id');
        $CarTypes = CarTypes::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        return view('CarTypes.edit')->with(compact('CarTypes'))->with(compact('lkp_active'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        //'password' => ['required', 'string', 'min:8', 'confirmed'],
        /* $this->validate($request, [
             'name' => ['required', 'string', 'max:255'],
             'email' => ['required', 'string', 'email', 'max:255'],
         ]);
        */
        $CarTypes = CarTypes::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        $CarTypes->carName = $request->input('carName');
        $CarTypes->arabicName = $request->input('arabicName');
        $CarTypes->Counterprice = $request->input('Counterprice');
        $CarTypes->priceByDistence = $request->input('priceByDistence');
        $CarTypes->priceByTime = $request->input('priceByTime');
        $CarTypes->rushHoursPBD = $request->input('rushHoursPBD');
        $CarTypes->rushHoursPBT = $request->input('rushHoursPBT');
        $CarTypes->NumberOfSeat = $request->input('NumberOfSeat');
        $CarTypes->status_id = $request->input('status_id');
        $CarTypes->save();
        return redirect('/CarTypes')->with('success', 'Done successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $CarTypes = CarTypes::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        // if(auth()->CarTypes()->id !== $CarTypes->CarTypes_id){
        //    return redirect('/CarTypes')->with('error','Unauthorized');
        // }
        if ($CarTypes->logo != 'noImage.jpg') {
            Storage::delete('public/app/storage' . $CarTypes->logo);
        }
        $CarTypes->delete();
        return redirect('/CarTypes')->with('success', 'Done successfully');
    }
}
